#
# RCS Version $Revision: 1.2 $
# RCS Last Change: $Date: 1998/12/14 01:49:26 $
# Original Author: Michael I. Schwartz, mschwart@nyx.net
#
# This file tests the various functions of profile
# Changes will be made to 
# the profile file <windows directory>\TEST.INI
# If all tests complete successfully, these changes are undone.
# If not, you may wish to clean them up by hand.
# Enhanced through suggestions by Jan Nijtmans, <Jan.Nijtmans@cmg.nl>
# to work with both Tclsh and Wish.

# If executed under Wish, set up a text pane for output. Otherwise, use stdout.
# Test for Tk by using tk_patchLevel variable
if [ info exist tk_patchLevel ] {
  set file [info script]
  if {![winfo exists .f]} {
    frame .f
    button .f.d -text Dismiss -command [list destroy .]
    pack .f.d -side left
    button .f.a -text "Run Again" -command [list source $file]
    pack .f.a -side right
    button .f.c -text "See Code" -command [list see_code $file]
    pack .f.c -side right
    pack .f -side top -fill x
    text .t -yscrollcommand [list .s set]
    scrollbar .s -command [list .t yview]
    pack .s -side right -fill y
    pack .t -side right -expand y -fill both
  } else {
    wm deiconify .
    raise .
  }
  .t delete 1.0 end

  proc puts args {
    # Put only the last argument--ignore any channels or flags
    .t insert end "[lindex $args end]\n"
    .t see end
    update
    # Slight pause for effect
    after 100
  }

  proc see_code file {
    if {![winfo exists .n]} {
      toplevel .n
      text .n.t -yscrollcommand [list .n.s set]
      scrollbar .n.s -command [list .n.t yview]
      pack .n.s -side right -fill y
      pack .n.t -side right -expand y -fill both
      set f [open $file r]
      .n.t insert end [read $f]
      close $f
      .n.t configure -state disabled
    } else {
      wm deiconify .n
      raise .n
    }
  }
}

# Output an informational message
if [ catch {
  set windir $env(SystemRoot)
} err ] {
  set windir "<windows directory>"
}

puts "\
# This file tests the various functions of profile\n\
# Changes will be made to the profile file \n\
# $windir\\TEST.INI\n\
# If all tests complete successfully, these changes are undone.\n\
# If not, you may wish to clean them up by hand.\n\n"


# Get the package
puts "Profile:Test1: Getting the package"

if [ catch { package require profile } err ] {
  puts "Error: $err"
  puts "Package require didn't work for profile. Trying load."
  if [ catch { load profile } err ] {
    puts "Error: $err" 
    puts "Can't load profile. Do it by hand, and source this script again."
    error "Giving up."
  }
}

# Get the version
puts "Profile:Test2: Get the version"
set ver [profile version]
puts "Profile:Test2: Success: Profile version: $ver"
if { $ver < "0.6.0.1" } {
  puts "Profile:Test2: Error: Version loaded seems to be lower than version expected!"
}

# Now test the profile
puts "Profile:Test3: Get a non-existent profile"
if [ catch { profile get -private test.ini -section test1 -default "***Failure default***" } err ] {
  puts "Profile:Test3: Error: profile get -private test.ini -section test1 failed\n$err\n"
} else {
  puts "Profile:Test3: Success: Initial profile get -private test.ini -section test1 returned\n\t$err, the specified default"
}

# Now, create the entry
puts "Profile:Test4: Set a non-existent profile"
if [ catch { profile set -private test.ini -section test1 -key albert -value osaurus } err ] {
  puts "Profile:Test4: Error in setting albert/osaurus\n$err"
} else {
  set retval [ profile get -private test.ini -section test1 -key albert ]
  if { $retval == "osaurus" } {
    puts "Profile:Test4: Succeeded in setting albert/osaurus"
  } else {
    puts "Profile:Test4: Error: Got :$retval: instead of :osaurus:"
  }
}

puts "Profile:Test5: Set another non-existent profile"
if [ catch { profile set -private test.ini -section test1 -key diplo -value docus } err ] {
  puts "Profile:Test5: Error in setting diplo/docus"
} else {
  set retval [profile get -private test.ini -section test1 -key diplo]
  if { $retval == "docus" } {
    puts "Profile:Test5: Succeeded in setting diplo/docus"
  } else {
    puts "Profile:Test5: Error: Got :$retval: instead of :docus:"
  }
}

puts "Profile:Test6: Delete an existing profile key"
profile delete -private test.ini -section test1 -key diplo
set retval [profile get -private test.ini -section test1 -key diplo -default "*****"]
if { $retval != "*****" } {
  puts "Profile:Test6: Failed in deletion of key diplo"
} else {
  puts "Profile:Test6: Succeeded in deletion of key diplo"
}

puts "Profile:Test7: Delete an existing profile section"
# Now delete the whole section
profile delete -private test.ini -section test1
set retval [profile get -private test.ini -section test1 -key albert -default "*****"]
if { $retval != "*****" } {
  puts "Profile:Test7: Failed in deletion of section test1"
} else {
  puts "Profile:Test7: Succeeded in deletion of section test1"
}


# This test only works under Win95 and WinNT
if [info exists tcl_platform(os) ] {
  if { $tcl_platform(os) == "Win32s" } {
    puts "Profile:Test8: Skipped since this requires Win95 or WinNT"
  } else {
    # Add some entries to the test profile
    profile set -private test.ini -section test1 -key diplo -value docus
    profile set -private test.ini -section test2 -key bronto -value saurus
    profile set -private test.ini -section test2 -key allo -value saurus
    profile set -private test.ini -section test2 -key tyranno -value "saurus rex"
    # Get the list of sections in a profile
    set retval [profile get -private test.ini]
    if { [llength $retval] == 2 } {
      puts "Profile:Test8: Succeeded in getting list of sections"
    } else {
      puts "Profile:Test8: Error in getting list of sections"
    }
    # Clean up
    profile delete -private test.ini -section test1
    profile delete -private test.ini -section test2
  }
} else {
  puts "Profile:Test8: Skipped since tcl_platform(os) does not exist"
}
